CREATE VIEW sod_case_action_v AS
 SELECT sod_case_info.id case_number,
    sod_case_info.state case_status,
    sod_case_info.policy,
    sod_case_info.policy_name,
    sod_policy.deleted policy_status,
    sod_case_info.violator_is_user,
    sod_case_info.violator_name,
    sod_case_info.violator_title,
    sod_case_action.id action_id,
    sod_case_action.action,
    sod_case_action.action_comment,
    sod_case_action.action_time,
    suser.display_name performed_by,
    sod_case_action.control_period,
    CASE
         WHEN (sod_case_action.control_period IS NOT NULL) THEN (sod_case_action.action_time + ( SELECT ((sod_case_action.control_period || ' days'))::interval AS "interval"))
         ELSE NULL::timestamp with time zone
    END approval_expiration,
    sod_removal_item.type item_type,
    CASE
        WHEN ((sod_removal_item.type) = 'PERMISSION') THEN spermission_v.name
        ELSE role_policy.name
    END item_name,
    count(cri.id) AS total_number,
    (
	 SELECT COUNT(*) 
	 FROM sod_case_action sca2
	 LEFT OUTER JOIN change_request_item cri ON cri.sod_case_action = sod_case_action.id
	 LEFT OUTER JOIN change_item_action cia ON cri.latest_action = cia.id
	 WHERE sca2.id = sod_case_action.id AND cia.change_item_status = 'PENDING' AND cri.provisioning_type = 'MANUAL'
	) pending_manual_number,
	(
	 SELECT COUNT(*) 
	 FROM sod_case_action sca2
	 LEFT OUTER JOIN change_request_item cri ON cri.sod_case_action = sod_case_action.id
	 LEFT OUTER JOIN change_item_action cia ON cri.latest_action = cia.id
	 WHERE sca2.id = sod_case_action.id AND cia.change_item_status = 'PENDING' AND cri.provisioning_type = 'IDENTITY_MANAGER'
	) pending_idm_number,
	(
	 SELECT COUNT(*) 
	 FROM sod_case_action sca2
	 LEFT OUTER JOIN change_request_item cri ON cri.sod_case_action = sod_case_action.id
	 LEFT OUTER JOIN change_item_action cia ON cri.latest_action = cia.id
	 WHERE sca2.id = sod_case_action.id AND cia.change_item_status = 'PENDING' AND cri.provisioning_type = 'EXTERNAL_WORKFLOW'
	) pending_ext_number,
	(
	 SELECT COUNT(*) 
	 FROM sod_case_action sca2
	 LEFT OUTER JOIN change_request_item cri ON cri.sod_case_action = sod_case_action.id
	 LEFT OUTER JOIN change_item_action cia ON cri.latest_action = cia.id
	 WHERE sca2.id = sod_case_action.id AND cia.change_item_status = 'INITIALIZED' 
	) initialized_number,
	(
	 SELECT COUNT(*) 
	 FROM sod_case_action sca2
	 LEFT OUTER JOIN change_request_item cri ON cri.sod_case_action = sod_case_action.id
	 LEFT OUTER JOIN change_item_action cia ON cri.latest_action = cia.id
	 WHERE sca2.id = sod_case_action.id AND cia.change_item_status = 'VERIFIED' 
	) verified_number,
	(
	 SELECT COUNT(*) 
	 FROM sod_case_action sca2
	 LEFT OUTER JOIN change_request_item cri ON cri.sod_case_action = sod_case_action.id
	 LEFT OUTER JOIN change_item_action cia ON cri.latest_action = cia.id
	 WHERE sca2.id = sod_case_action.id AND cia.change_item_status = 'REFUSED' 
	) refused_number,
	(
	 SELECT COUNT(*) 
	 FROM sod_case_action sca2
	 LEFT OUTER JOIN change_request_item cri ON cri.sod_case_action = sod_case_action.id
	 LEFT OUTER JOIN change_item_action cia ON cri.latest_action = cia.id
	 WHERE sca2.id = sod_case_action.id AND cia.change_item_status = 'VERIFICATION_IGNORED' 
	) verification_ignored_number,
	(
	 SELECT COUNT(*) 
	 FROM sod_case_action sca2
	 LEFT OUTER JOIN change_request_item cri ON cri.sod_case_action = sod_case_action.id
	 LEFT OUTER JOIN change_item_action cia ON cri.latest_action = cia.id
	 WHERE sca2.id = sod_case_action.id AND cia.change_item_status = 'NOT_VERIFIED' 
	) not_verified_number,
	(
	 SELECT COUNT(*) 
	 FROM sod_case_action sca2
	 LEFT OUTER JOIN change_request_item cri ON cri.sod_case_action = sod_case_action.id
	 LEFT OUTER JOIN change_item_action cia ON cri.latest_action = cia.id
	 WHERE sca2.id = sod_case_action.id AND cia.change_item_status = 'VERIFICATION_TIMEOUT' 
	) verification_timeout_number,
	(
	 SELECT COUNT(*) 
	 FROM sod_case_action sca2
	 LEFT OUTER JOIN change_request_item cri ON cri.sod_case_action = sod_case_action.id
	 LEFT OUTER JOIN change_item_action cia ON cri.latest_action = cia.id
	 WHERE sca2.id = sod_case_action.id AND cia.change_item_status = 'ERROR' 
	) error_number,
	(
	 SELECT COUNT(*) 
	 FROM sod_case_action sca2
	 LEFT OUTER JOIN change_request_item cri ON cri.sod_case_action = sod_case_action.id
	 LEFT OUTER JOIN change_item_action cia ON cri.latest_action = cia.id
	 WHERE sca2.id = sod_case_action.id AND cia.change_item_status = 'COMPLETED' AND cri.provisioning_type = 'MANUAL'
	) completed_manual_number,
	(
	 SELECT COUNT(*) 
	 FROM sod_case_action sca2
	 LEFT OUTER JOIN change_request_item cri ON cri.sod_case_action = sod_case_action.id
	 LEFT OUTER JOIN change_item_action cia ON cri.latest_action = cia.id
	 WHERE sca2.id = sod_case_action.id AND cia.change_item_status = 'COMPLETED' AND cri.provisioning_type = 'IDENTITY_MANAGER'
	) completed_idm_number,
	(
	 SELECT COUNT(*) 
	 FROM sod_case_action sca2
	 LEFT OUTER JOIN change_request_item cri ON cri.sod_case_action = sod_case_action.id
	 LEFT OUTER JOIN change_item_action cia ON cri.latest_action = cia.id
	 WHERE sca2.id = sod_case_action.id AND cia.change_item_status = 'COMPLETED' AND cri.provisioning_type = 'EXTERNAL_WORKFLOW'
	) completed_ext_number,
	(
	 SELECT COUNT(*) 
	 FROM sod_case_action sca2
	 LEFT OUTER JOIN change_request_item cri ON cri.sod_case_action = sod_case_action.id
	 LEFT OUTER JOIN change_item_action cia ON cri.latest_action = cia.id
	 WHERE sca2.id = sod_case_action.id AND cia.change_item_status = 'IN_PROGRESS' 
	) in_progress_number
   FROM sod_case_info
     JOIN sod_policy ON sod_policy.id = sod_case_info.policy
     JOIN sod_case_action ON sod_case_action.sod_case = sod_case_info.id
     LEFT JOIN sod_removal_item ON sod_removal_item.sod_case_action = sod_case_action.id
     LEFT JOIN spermission_v ON spermission_v.unique_permission_id = sod_removal_item.unique_id
     LEFT JOIN role_policy ON role_policy.unique_policy_id = sod_removal_item.unique_id AND role_policy.deleted = false
     LEFT JOIN suser ON sod_case_action.performed_by = suser.unique_user_id AND suser.deleted = false AND suser.effective = true
     LEFT JOIN change_request_item cri ON cri.sod_case_action = sod_case_action.id
   GROUP BY sod_case_info.id, sod_case_info.state, sod_case_info.policy, sod_case_info.policy_name, sod_policy.deleted, sod_case_info.violator_is_user, sod_case_info.violator_name, sod_case_info.violator_title, sod_case_action.id, sod_case_action.action, sod_case_action.action_comment, sod_case_action.action_time, suser.display_name, sod_case_action.control_period, spermission_v.name, role_policy.name, sod_removal_item.type
  ORDER BY sod_case_info.policy_name, sod_case_info.policy, sod_case_info.violator_name, sod_case_action.action_time;

    ALTER TABLE public.sod_case_action_v
  OWNER TO igops;
GRANT ALL ON TABLE public.sod_case_action_v TO igops;
GRANT SELECT ON TABLE public.sod_case_action_v TO ig_report_role;